@@ -1,9 +1,11 @@
-// Copyright (C) 2015 Conrad Sanderson
-// Copyright (C) 2015 NICTA (www.nicta.com.au)
+// Copyright (C) 2015-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup fn_cumprod
@@ -12,6 +14,7 @@
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename
 enable_if2
@@ -29,6 +32,7 @@ cumprod(const T1& X)
 
 
 template<typename T1>
+arma_warn_unused
 arma_inline
 typename
 enable_if2
@@ -46,8 +50,8 @@ cumprod(const T1& X, const uword dim)
 
 
 template<typename T>
-arma_inline
 arma_warn_unused
+arma_inline
 const typename arma_scalar_only<T>::result &
 cumprod(const T& x)
   {
