@@ -1,4 +1,4 @@
-// Copyright (C) 2008-2015 National ICT Australia (NICTA)
+// Copyright (C) 2008-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -45,6 +45,7 @@ eig_sym
 
 //! Eigenvalues of real/complex symmetric/hermitian matrix X
 template<typename T1>
+arma_warn_unused
 inline
 Col<typename T1::pod_type>
 eig_sym
@@ -62,7 +63,7 @@ eig_sym
   if(status == false)
     {
     out.reset();
-    arma_bad("eig_sym(): decomposition failed");
+    arma_stop_runtime_error("eig_sym(): decomposition failed");
     }
   
   return out;
