@@ -1,9 +1,11 @@
-// Copyright (C) 2013-2014 Conrad Sanderson
-// Copyright (C) 2013-2014 NICTA (www.nicta.com.au)
+// Copyright (C) 2013-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup fn_vectorise
@@ -12,6 +14,7 @@
 
 
 template<typename T1>
+arma_warn_unused
 inline
 typename
 enable_if2
@@ -29,6 +32,7 @@ vectorise(const T1& X)
 
 
 template<typename T1>
+arma_warn_unused
 inline
 typename
 enable_if2
@@ -48,6 +52,7 @@ vectorise(const T1& X, const uword dim)
 
 
 template<typename T1>
+arma_warn_unused
 inline
 Col<typename T1::elem_type>
 vectorise(const BaseCube<typename T1::elem_type, T1>& X)
