@@ -1,9 +1,11 @@
-// Copyright (C) 2010-2013 NICTA (www.nicta.com.au)
-// Copyright (C) 2010-2013 Conrad Sanderson
+// Copyright (C) 2010-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 
@@ -33,7 +35,7 @@ glue_cross::apply(Mat<typename T1::elem_type>& out, const Glue<T1, T2, glue_cros
   
   eT* out_mem = out.memptr();
   
-  if( (Proxy<T1>::prefer_at_accessor == false) && (Proxy<T2>::prefer_at_accessor == false) )
+  if( (Proxy<T1>::use_at == false) && (Proxy<T2>::use_at == false) )
     {
     typename Proxy<T1>::ea_type A = PA.get_ea();
     typename Proxy<T2>::ea_type B = PB.get_ea();
