@@ -1,4 +1,4 @@
-// Copyright (C) 2008-2014 National ICT Australia (NICTA)
+// Copyright (C) 2008-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -16,7 +16,6 @@
 //! for two arrays, generic version for non-complex values
 template<typename eT>
 arma_hot
-arma_pure
 arma_inline
 typename arma_not_cx<eT>::result
 op_dot::direct_dot_arma(const uword n_elem, const eT* const A, const eT* const B)
@@ -62,7 +61,6 @@ op_dot::direct_dot_arma(const uword n_elem, const eT* const A, const eT* const B
 //! for two arrays, generic version for complex values
 template<typename eT>
 arma_hot
-arma_pure
 inline
 typename arma_cx_only<eT>::result
 op_dot::direct_dot_arma(const uword n_elem, const eT* const A, const eT* const B)
@@ -97,7 +95,6 @@ op_dot::direct_dot_arma(const uword n_elem, const eT* const A, const eT* const B
 //! for two arrays, float and double version
 template<typename eT>
 arma_hot
-arma_pure
 inline
 typename arma_real_only<eT>::result
 op_dot::direct_dot(const uword n_elem, const eT* const A, const eT* const B)
@@ -136,7 +133,6 @@ op_dot::direct_dot(const uword n_elem, const eT* const A, const eT* const B)
 template<typename eT>
 inline
 arma_hot
-arma_pure
 typename arma_cx_only<eT>::result
 op_dot::direct_dot(const uword n_elem, const eT* const A, const eT* const B)
   {
@@ -171,7 +167,6 @@ op_dot::direct_dot(const uword n_elem, const eT* const A, const eT* const B)
 //! for two arrays, integral version
 template<typename eT>
 arma_hot
-arma_pure
 inline
 typename arma_integral_only<eT>::result
 op_dot::direct_dot(const uword n_elem, const eT* const A, const eT* const B)
@@ -185,7 +180,6 @@ op_dot::direct_dot(const uword n_elem, const eT* const A, const eT* const B)
 //! for three arrays
 template<typename eT>
 arma_hot
-arma_pure
 inline
 eT
 op_dot::direct_dot(const uword n_elem, const eT* const A, const eT* const B, const eT* C)
@@ -212,11 +206,11 @@ op_dot::apply(const T1& X, const T2& Y)
   {
   arma_extra_debug_sigprint();
   
-  const bool prefer_at_accessor = (Proxy<T1>::prefer_at_accessor) || (Proxy<T2>::prefer_at_accessor);
+  const bool use_at = (Proxy<T1>::use_at) || (Proxy<T2>::use_at);
   
   const bool have_direct_mem = ((is_Mat<T1>::value || is_subview_col<T1>::value) && (is_Mat<T2>::value || is_subview_col<T2>::value));
   
-  if(prefer_at_accessor || have_direct_mem)
+  if(use_at || have_direct_mem)
     {
     const quasi_unwrap<T1> A(X);
     const quasi_unwrap<T2> B(Y);
@@ -382,7 +376,6 @@ op_norm_dot::apply(const T1& X, const T2& Y)
 
 template<typename eT>
 arma_hot
-arma_pure
 inline
 eT
 op_cdot::direct_cdot_arma(const uword n_elem, const eT* const A, const eT* const B)
@@ -416,7 +409,6 @@ op_cdot::direct_cdot_arma(const uword n_elem, const eT* const A, const eT* const
 
 template<typename eT>
 arma_hot
-arma_pure
 inline
 eT
 op_cdot::direct_cdot(const uword n_elem, const eT* const A, const eT* const B)
@@ -525,9 +517,9 @@ op_cdot::apply_proxy(const T1& X, const T2& Y)
   typedef typename Proxy<T1>::ea_type ea_type1;
   typedef typename Proxy<T2>::ea_type ea_type2;
   
-  const bool prefer_at_accessor = (Proxy<T1>::prefer_at_accessor) || (Proxy<T2>::prefer_at_accessor);
+  const bool use_at = (Proxy<T1>::use_at) || (Proxy<T2>::use_at);
   
-  if(prefer_at_accessor == false)
+  if(use_at == false)
     {
     const Proxy<T1> PA(X);
     const Proxy<T2> PB(Y);
