@@ -277,4 +277,94 @@ op_abs::apply( Cube<typename T1::pod_type>& out, const mtOpCube<typename T1::pod
 
 
 
+template<typename T1>
+inline
+void
+op_arg::apply( Mat<typename T1::pod_type>& out, const mtOp<typename T1::pod_type, T1, op_arg>& X )
+  {
+  arma_extra_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
+  typedef typename T1::pod_type   T;
+  
+  const Proxy<T1> P(X.m);
+  
+  const uword n_rows = P.get_n_rows();
+  const uword n_cols = P.get_n_cols();
+  
+  out.set_size(n_rows, n_cols);
+  
+  T* out_mem = out.memptr();
+  
+  if(Proxy<T1>::use_at == false)
+    {
+    typedef typename Proxy<T1>::ea_type ea_type;
+    
+    const uword   n_elem  = P.get_n_elem();
+          ea_type A       = P.get_ea();
+    
+    for(uword i=0; i < n_elem; ++i)
+      {
+      out_mem[i] = arma_arg<eT>::eval( A[i] );
+      }
+    }
+  else
+    {
+    for(uword col=0; col < n_cols; ++col)
+    for(uword row=0; row < n_rows; ++row)
+      {
+      *out_mem = arma_arg<eT>::eval( P.at(row,col) );
+      out_mem++;
+      }
+    }
+  }
+
+
+
+template<typename T1>
+inline
+void
+op_arg::apply( Cube<typename T1::pod_type>& out, const mtOpCube<typename T1::pod_type, T1, op_arg>& X )
+  {
+  arma_extra_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
+  typedef typename T1::pod_type   T;
+  
+  const ProxyCube<T1> P(X.m);
+  
+  const uword n_rows   = P.get_n_rows();
+  const uword n_cols   = P.get_n_cols();
+  const uword n_slices = P.get_n_slices();
+  
+  out.set_size(n_rows, n_cols, n_slices);
+  
+  T* out_mem = out.memptr();
+
+  if(ProxyCube<T1>::use_at == false)
+    {
+    typedef typename ProxyCube<T1>::ea_type ea_type;
+    
+    const uword   n_elem  = P.get_n_elem();
+          ea_type A       = P.get_ea();
+    
+    for(uword i=0; i < n_elem; ++i)
+      {
+      out_mem[i] = arma_arg<eT>::eval( A[i] );
+      }
+    }
+  else
+    {
+    for(uword slice=0; slice < n_slices; ++slice)
+    for(uword col=0;   col   < n_cols;   ++col  )
+    for(uword row=0;   row   < n_rows;   ++row  )
+      {
+      *out_mem = arma_arg<eT>::eval( P.at(row,col,slice) );
+      out_mem++;
+      }
+    }
+  }
+
+
+
 //! @}
