@@ -1,4 +1,4 @@
-// Copyright (C) 2009-2011 National ICT Australia (NICTA)
+// Copyright (C) 2009-2016 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -290,6 +290,18 @@ running_stat<eT>::max() const
 
 
 
+template<typename eT>
+inline
+eT
+running_stat<eT>::range() const
+  {
+  arma_extra_debug_sigprint();
+  
+  return (max_val - min_val);
+  }
+
+
+
 //! number of samples so far
 template<typename eT>
 inline
